@@ -159,6 +159,16 @@ def get_current_user_raw(token: str = Depends(oath2_scheme)):
         raise DoormanAuthException(message=e)
 
 
+from datetime import datetime
+
+
+def last_seen_from_uid(uid: str) -> Optional[datetime]:
+    timestamp_str = R.get(uid)
+    if not timestamp_str:
+        return None
+    return datetime.fromtimestamp(int(timestamp_str))
+
+
 GET_USER = Depends(get_current_user)
 GET_USER_OR_NONE = Depends(get_current_user_or_none)
 
